# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/SettingsWidget.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_SettingsWidget(object):
    def setupUi(self, SettingsWidget):
        SettingsWidget.setObjectName("SettingsWidget")
        SettingsWidget.resize(417, 697)
        SettingsWidget.setMinimumSize(QtCore.QSize(0, 0))
        SettingsWidget.setMaximumSize(QtCore.QSize(457, 16777215))
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(SettingsWidget)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox = QtWidgets.QGroupBox(SettingsWidget)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.frame_source = QtWidgets.QFrame(self.groupBox)
        self.frame_source.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_source.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_source.setObjectName("frame_source")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.frame_source)
        self.horizontalLayout_5.setContentsMargins(3, 3, 3, 3)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_26 = QtWidgets.QLabel(self.frame_source)
        self.label_26.setMinimumSize(QtCore.QSize(125, 0))
        self.label_26.setObjectName("label_26")
        self.horizontalLayout_5.addWidget(self.label_26)
        self.cmb_source = QtWidgets.QComboBox(self.frame_source)
        self.cmb_source.setMinimumSize(QtCore.QSize(200, 0))
        self.cmb_source.setObjectName("cmb_source")
        self.horizontalLayout_5.addWidget(self.cmb_source)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem)
        self.verticalLayout_3.addWidget(self.frame_source)
        self.frame_folder = QtWidgets.QFrame(self.groupBox)
        self.frame_folder.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_folder.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_folder.setObjectName("frame_folder")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.frame_folder)
        self.horizontalLayout_4.setContentsMargins(3, 3, 3, 3)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_23 = QtWidgets.QLabel(self.frame_folder)
        self.label_23.setMinimumSize(QtCore.QSize(125, 0))
        self.label_23.setObjectName("label_23")
        self.horizontalLayout_4.addWidget(self.label_23)
        self.cmb_path = QtWidgets.QComboBox(self.frame_folder)
        self.cmb_path.setMinimumSize(QtCore.QSize(200, 0))
        self.cmb_path.setObjectName("cmb_path")
        self.horizontalLayout_4.addWidget(self.cmb_path)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.verticalLayout_3.addWidget(self.frame_folder)
        self.frame_exposure = QtWidgets.QFrame(self.groupBox)
        self.frame_exposure.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_exposure.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_exposure.setObjectName("frame_exposure")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.frame_exposure)
        self.horizontalLayout_6.setContentsMargins(3, 3, 3, 3)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label = QtWidgets.QLabel(self.frame_exposure)
        self.label.setMinimumSize(QtCore.QSize(125, 0))
        self.label.setObjectName("label")
        self.horizontalLayout_6.addWidget(self.label)
        self.sb_exposure = QtWidgets.QDoubleSpinBox(self.frame_exposure)
        self.sb_exposure.setMinimumSize(QtCore.QSize(75, 0))
        self.sb_exposure.setMaximumSize(QtCore.QSize(75, 16777215))
        self.sb_exposure.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sb_exposure.setDecimals(6)
        self.sb_exposure.setMinimum(1e-06)
        self.sb_exposure.setProperty("value", 1.0)
        self.sb_exposure.setObjectName("sb_exposure")
        self.horizontalLayout_6.addWidget(self.sb_exposure)
        self.label_3 = QtWidgets.QLabel(self.frame_exposure)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_6.addWidget(self.label_3)
        self.sb_gain = QtWidgets.QSpinBox(self.frame_exposure)
        self.sb_gain.setMinimumSize(QtCore.QSize(75, 0))
        self.sb_gain.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sb_gain.setMaximum(22)
        self.sb_gain.setObjectName("sb_gain")
        self.horizontalLayout_6.addWidget(self.sb_gain)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem2)
        self.verticalLayout_3.addWidget(self.frame_exposure)
        self.verticalLayout_2.addWidget(self.groupBox)
        self.groupBox_4 = QtWidgets.QGroupBox(SettingsWidget)
        self.groupBox_4.setObjectName("groupBox_4")
        self.vl_levels = QtWidgets.QVBoxLayout(self.groupBox_4)
        self.vl_levels.setObjectName("vl_levels")
        self.chk_auto_levels = QtWidgets.QCheckBox(self.groupBox_4)
        self.chk_auto_levels.setChecked(True)
        self.chk_auto_levels.setObjectName("chk_auto_levels")
        self.vl_levels.addWidget(self.chk_auto_levels)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_2 = QtWidgets.QLabel(self.groupBox_4)
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_11.addWidget(self.label_2)
        self.sb_min_level = QtWidgets.QDoubleSpinBox(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sb_min_level.sizePolicy().hasHeightForWidth())
        self.sb_min_level.setSizePolicy(sizePolicy)
        self.sb_min_level.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sb_min_level.setMaximum(300.0)
        self.sb_min_level.setObjectName("sb_min_level")
        self.horizontalLayout_11.addWidget(self.sb_min_level)
        self.label_4 = QtWidgets.QLabel(self.groupBox_4)
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_11.addWidget(self.label_4)
        self.sb_max_level = QtWidgets.QDoubleSpinBox(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sb_max_level.sizePolicy().hasHeightForWidth())
        self.sb_max_level.setSizePolicy(sizePolicy)
        self.sb_max_level.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sb_max_level.setMaximum(300.0)
        self.sb_max_level.setProperty("value", 1.0)
        self.sb_max_level.setObjectName("sb_max_level")
        self.horizontalLayout_11.addWidget(self.sb_max_level)
        self.vl_levels.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.rb_lin_level = QtWidgets.QRadioButton(self.groupBox_4)
        self.rb_lin_level.setChecked(True)
        self.rb_lin_level.setObjectName("rb_lin_level")
        self.bg_level = QtWidgets.QButtonGroup(SettingsWidget)
        self.bg_level.setObjectName("bg_level")
        self.bg_level.addButton(self.rb_lin_level)
        self.horizontalLayout_13.addWidget(self.rb_lin_level)
        self.rb_log_level = QtWidgets.QRadioButton(self.groupBox_4)
        self.rb_log_level.setObjectName("rb_log_level")
        self.bg_level.addButton(self.rb_log_level)
        self.horizontalLayout_13.addWidget(self.rb_log_level)
        self.rb_sqrt_level = QtWidgets.QRadioButton(self.groupBox_4)
        self.rb_sqrt_level.setObjectName("rb_sqrt_level")
        self.bg_level.addButton(self.rb_sqrt_level)
        self.horizontalLayout_13.addWidget(self.rb_sqrt_level)
        self.vl_levels.addLayout(self.horizontalLayout_13)
        self.verticalLayout_2.addWidget(self.groupBox_4)
        self.chk_additional_settings = QtWidgets.QCheckBox(SettingsWidget)
        self.chk_additional_settings.setObjectName("chk_additional_settings")
        self.verticalLayout_2.addWidget(self.chk_additional_settings)
        self.gb_ext_settings = QtWidgets.QGroupBox(SettingsWidget)
        self.gb_ext_settings.setCheckable(False)
        self.gb_ext_settings.setObjectName("gb_ext_settings")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.gb_ext_settings)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(6)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame_Cut = QtWidgets.QFrame(self.gb_ext_settings)
        self.frame_Cut.setObjectName("frame_Cut")
        self.gridLayout = QtWidgets.QGridLayout(self.frame_Cut)
        self.gridLayout.setObjectName("gridLayout")
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem3, 0, 5, 1, 1)
        self.sb_view_h = QtWidgets.QSpinBox(self.frame_Cut)
        self.sb_view_h.setMinimum(-1)
        self.sb_view_h.setMaximum(9999)
        self.sb_view_h.setSingleStep(4)
        self.sb_view_h.setObjectName("sb_view_h")
        self.gridLayout.addWidget(self.sb_view_h, 1, 4, 1, 1)
        self.label_22 = QtWidgets.QLabel(self.frame_Cut)
        self.label_22.setMinimumSize(QtCore.QSize(100, 0))
        self.label_22.setObjectName("label_22")
        self.gridLayout.addWidget(self.label_22, 0, 0, 2, 1)
        self.sb_view_w = QtWidgets.QSpinBox(self.frame_Cut)
        self.sb_view_w.setMinimum(-1)
        self.sb_view_w.setMaximum(9999)
        self.sb_view_w.setSingleStep(4)
        self.sb_view_w.setObjectName("sb_view_w")
        self.gridLayout.addWidget(self.sb_view_w, 1, 2, 1, 1)
        self.label_19 = QtWidgets.QLabel(self.frame_Cut)
        self.label_19.setMinimumSize(QtCore.QSize(20, 0))
        self.label_19.setObjectName("label_19")
        self.gridLayout.addWidget(self.label_19, 0, 1, 1, 1)
        self.sb_view_y = QtWidgets.QSpinBox(self.frame_Cut)
        self.sb_view_y.setMinimumSize(QtCore.QSize(75, 0))
        self.sb_view_y.setMaximum(9999)
        self.sb_view_y.setSingleStep(4)
        self.sb_view_y.setObjectName("sb_view_y")
        self.gridLayout.addWidget(self.sb_view_y, 0, 4, 1, 1)
        self.label_28 = QtWidgets.QLabel(self.frame_Cut)
        self.label_28.setObjectName("label_28")
        self.gridLayout.addWidget(self.label_28, 1, 3, 1, 1)
        self.label_20 = QtWidgets.QLabel(self.frame_Cut)
        self.label_20.setMinimumSize(QtCore.QSize(25, 0))
        self.label_20.setObjectName("label_20")
        self.gridLayout.addWidget(self.label_20, 0, 3, 1, 1)
        self.sb_view_x = QtWidgets.QSpinBox(self.frame_Cut)
        self.sb_view_x.setMinimumSize(QtCore.QSize(75, 0))
        self.sb_view_x.setMaximum(9999)
        self.sb_view_x.setSingleStep(4)
        self.sb_view_x.setObjectName("sb_view_x")
        self.gridLayout.addWidget(self.sb_view_x, 0, 2, 1, 1)
        self.label_27 = QtWidgets.QLabel(self.frame_Cut)
        self.label_27.setObjectName("label_27")
        self.gridLayout.addWidget(self.label_27, 1, 1, 1, 1)
        self.verticalLayout.addWidget(self.frame_Cut)
        self.frame_reduce = QtWidgets.QFrame(self.gb_ext_settings)
        self.frame_reduce.setObjectName("frame_reduce")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.frame_reduce)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.lbFps_2 = QtWidgets.QLabel(self.frame_reduce)
        self.lbFps_2.setMinimumSize(QtCore.QSize(125, 0))
        self.lbFps_2.setObjectName("lbFps_2")
        self.horizontalLayout_9.addWidget(self.lbFps_2)
        self.sb_reduce = QtWidgets.QSpinBox(self.frame_reduce)
        self.sb_reduce.setMinimumSize(QtCore.QSize(75, 0))
        self.sb_reduce.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sb_reduce.setMinimum(1)
        self.sb_reduce.setObjectName("sb_reduce")
        self.horizontalLayout_9.addWidget(self.sb_reduce)
        self.lbFps_3 = QtWidgets.QLabel(self.frame_reduce)
        self.lbFps_3.setObjectName("lbFps_3")
        self.horizontalLayout_9.addWidget(self.lbFps_3)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem4)
        self.verticalLayout.addWidget(self.frame_reduce)
        self.frame_dark_Image = QtWidgets.QFrame(self.gb_ext_settings)
        self.frame_dark_Image.setObjectName("frame_dark_Image")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.frame_dark_Image)
        self.gridLayout_2.setContentsMargins(1, 1, 1, 1)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.chk_dark_image = QtWidgets.QCheckBox(self.frame_dark_Image)
        self.chk_dark_image.setObjectName("chk_dark_image")
        self.gridLayout_2.addWidget(self.chk_dark_image, 0, 0, 1, 1)
        self.but_acq_dark_image = QtWidgets.QPushButton(self.frame_dark_Image)
        self.but_acq_dark_image.setObjectName("but_acq_dark_image")
        self.gridLayout_2.addWidget(self.but_acq_dark_image, 1, 0, 1, 1)
        self.but_load_dark_image = QtWidgets.QPushButton(self.frame_dark_Image)
        self.but_load_dark_image.setObjectName("but_load_dark_image")
        self.gridLayout_2.addWidget(self.but_load_dark_image, 1, 1, 1, 1)
        self.but_save_dark_image = QtWidgets.QPushButton(self.frame_dark_Image)
        self.but_save_dark_image.setObjectName("but_save_dark_image")
        self.gridLayout_2.addWidget(self.but_save_dark_image, 1, 2, 1, 1)
        self.verticalLayout.addWidget(self.frame_dark_Image)
        self.frame_FPS = QtWidgets.QFrame(self.gb_ext_settings)
        self.frame_FPS.setObjectName("frame_FPS")
        self.layout_FPS = QtWidgets.QHBoxLayout(self.frame_FPS)
        self.layout_FPS.setObjectName("layout_FPS")
        self.lbFps = QtWidgets.QLabel(self.frame_FPS)
        self.lbFps.setMinimumSize(QtCore.QSize(125, 0))
        self.lbFps.setObjectName("lbFps")
        self.layout_FPS.addWidget(self.lbFps)
        self.sb_FPS = QtWidgets.QSpinBox(self.frame_FPS)
        self.sb_FPS.setMinimumSize(QtCore.QSize(75, 0))
        self.sb_FPS.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.sb_FPS.setMinimum(1)
        self.sb_FPS.setObjectName("sb_FPS")
        self.layout_FPS.addWidget(self.sb_FPS)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.layout_FPS.addItem(spacerItem5)
        self.verticalLayout.addWidget(self.frame_FPS)
        self.frame_background = QtWidgets.QFrame(self.gb_ext_settings)
        self.frame_background.setObjectName("frame_background")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.frame_background)
        self.gridLayout_3.setContentsMargins(1, 1, 1, 1)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.chk_background = QtWidgets.QCheckBox(self.frame_background)
        self.chk_background.setObjectName("chk_background")
        self.gridLayout_3.addWidget(self.chk_background, 0, 0, 1, 2)
        self.label_6 = QtWidgets.QLabel(self.frame_background)
        self.label_6.setObjectName("label_6")
        self.gridLayout_3.addWidget(self.label_6, 0, 3, 1, 1)
        self.dsb_sigmas = QtWidgets.QDoubleSpinBox(self.frame_background)
        self.dsb_sigmas.setObjectName("dsb_sigmas")
        self.gridLayout_3.addWidget(self.dsb_sigmas, 0, 2, 1, 1)
        self.verticalLayout.addWidget(self.frame_background)
        self.gb_screen_motor = QtWidgets.QGroupBox(self.gb_ext_settings)
        self.gb_screen_motor.setObjectName("gb_screen_motor")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.gb_screen_motor)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lb_screen_status = QtWidgets.QLabel(self.gb_screen_motor)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.lb_screen_status.setFont(font)
        self.lb_screen_status.setObjectName("lb_screen_status")
        self.horizontalLayout_2.addWidget(self.lb_screen_status)
        self.but_in_out = QtWidgets.QPushButton(self.gb_screen_motor)
        self.but_in_out.setMinimumSize(QtCore.QSize(50, 0))
        self.but_in_out.setObjectName("but_in_out")
        self.horizontalLayout_2.addWidget(self.but_in_out)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem6)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem7)
        self.chk_auto_screen = QtWidgets.QCheckBox(self.gb_screen_motor)
        self.chk_auto_screen.setObjectName("chk_auto_screen")
        self.horizontalLayout_2.addWidget(self.chk_auto_screen)
        self.verticalLayout.addWidget(self.gb_screen_motor)
        self.tbAllParams = QtWidgets.QPushButton(self.gb_ext_settings)
        self.tbAllParams.setObjectName("tbAllParams")
        self.verticalLayout.addWidget(self.tbAllParams)
        self.verticalLayout_2.addWidget(self.gb_ext_settings)
        spacerItem8 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem8)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem9)

        self.retranslateUi(SettingsWidget)
        QtCore.QMetaObject.connectSlotsByName(SettingsWidget)

    def retranslateUi(self, SettingsWidget):
        _translate = QtCore.QCoreApplication.translate
        SettingsWidget.setWindowTitle(_translate("SettingsWidget", "Form"))
        self.groupBox.setTitle(_translate("SettingsWidget", "Image settings"))
        self.label_26.setText(_translate("SettingsWidget", "Source:"))
        self.label_23.setText(_translate("SettingsWidget", "Folder to monitor:"))
        self.label.setText(_translate("SettingsWidget", "Exposure:"))
        self.label_3.setText(_translate("SettingsWidget", "Gain:"))
        self.groupBox_4.setTitle(_translate("SettingsWidget", "Levels"))
        self.chk_auto_levels.setText(_translate("SettingsWidget", "Auto Levels"))
        self.label_2.setText(_translate("SettingsWidget", "Min:"))
        self.label_4.setText(_translate("SettingsWidget", "Max:"))
        self.rb_lin_level.setText(_translate("SettingsWidget", "Lin"))
        self.rb_log_level.setText(_translate("SettingsWidget", "Log"))
        self.rb_sqrt_level.setText(_translate("SettingsWidget", "Sqrt"))
        self.chk_additional_settings.setText(_translate("SettingsWidget", "Show additional settings"))
        self.gb_ext_settings.setTitle(_translate("SettingsWidget", "Additional settings"))
        self.label_22.setText(_translate("SettingsWidget", "Cut image:"))
        self.label_19.setText(_translate("SettingsWidget", "X:"))
        self.label_28.setText(_translate("SettingsWidget", "H:"))
        self.label_20.setText(_translate("SettingsWidget", "Y:"))
        self.label_27.setText(_translate("SettingsWidget", "W:"))
        self.lbFps_2.setText(_translate("SettingsWidget", "Reduce resolution"))
        self.lbFps_3.setText(_translate("SettingsWidget", "times"))
        self.chk_dark_image.setText(_translate("SettingsWidget", "Substract dark image"))
        self.but_acq_dark_image.setText(_translate("SettingsWidget", "Acquire Dark Image"))
        self.but_load_dark_image.setText(_translate("SettingsWidget", "Load Dark Image"))
        self.but_save_dark_image.setText(_translate("SettingsWidget", "Save Dark Image"))
        self.lbFps.setText(_translate("SettingsWidget", "Limit FPS"))
        self.chk_background.setText(_translate("SettingsWidget", "Substract mean background:"))
        self.label_6.setText(_translate("SettingsWidget", "sigmas"))
        self.gb_screen_motor.setTitle(_translate("SettingsWidget", "Screen control"))
        self.lb_screen_status.setText(_translate("SettingsWidget", "Screen In"))
        self.but_in_out.setText(_translate("SettingsWidget", "Move In"))
        self.chk_auto_screen.setText(_translate("SettingsWidget", "Enable auto screen"))
        self.tbAllParams.setText(_translate("SettingsWidget", "Open ATK panel"))

