# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/ROI.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Roi(object):
    def setupUi(self, Roi):
        Roi.setObjectName("Roi")
        Roi.resize(416, 334)
        self.verticalLayout = QtWidgets.QVBoxLayout(Roi)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox_3 = QtWidgets.QGroupBox(Roi)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.sb_roi_y = QtWidgets.QSpinBox(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sb_roi_y.sizePolicy().hasHeightForWidth())
        self.sb_roi_y.setSizePolicy(sizePolicy)
        self.sb_roi_y.setMaximum(9999)
        self.sb_roi_y.setObjectName("sb_roi_y")
        self.gridLayout_3.addWidget(self.sb_roi_y, 2, 3, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_3)
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.gridLayout_3.addWidget(self.label_6, 2, 0, 1, 1)
        self.chb_roi_enable = QtWidgets.QCheckBox(self.groupBox_3)
        self.chb_roi_enable.setObjectName("chb_roi_enable")
        self.gridLayout_3.addWidget(self.chb_roi_enable, 0, 0, 1, 1)
        self.sb_roi_x = QtWidgets.QSpinBox(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sb_roi_x.sizePolicy().hasHeightForWidth())
        self.sb_roi_x.setSizePolicy(sizePolicy)
        self.sb_roi_x.setMaximum(9999)
        self.sb_roi_x.setObjectName("sb_roi_x")
        self.gridLayout_3.addWidget(self.sb_roi_x, 2, 1, 1, 1)
        self.sb_roi_h = QtWidgets.QSpinBox(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sb_roi_h.sizePolicy().hasHeightForWidth())
        self.sb_roi_h.setSizePolicy(sizePolicy)
        self.sb_roi_h.setMaximum(9999)
        self.sb_roi_h.setObjectName("sb_roi_h")
        self.gridLayout_3.addWidget(self.sb_roi_h, 3, 3, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.groupBox_3)
        self.label_8.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_8.setObjectName("label_8")
        self.gridLayout_3.addWidget(self.label_8, 3, 2, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.groupBox_3)
        self.label_9.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_9.setObjectName("label_9")
        self.gridLayout_3.addWidget(self.label_9, 3, 0, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.groupBox_3)
        self.label_7.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_7.setObjectName("label_7")
        self.gridLayout_3.addWidget(self.label_7, 2, 2, 1, 1)
        self.sb_roi_w = QtWidgets.QSpinBox(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sb_roi_w.sizePolicy().hasHeightForWidth())
        self.sb_roi_w.setSizePolicy(sizePolicy)
        self.sb_roi_w.setMaximum(9999)
        self.sb_roi_w.setObjectName("sb_roi_w")
        self.gridLayout_3.addWidget(self.sb_roi_w, 3, 1, 1, 1)
        self.but_delete = QtWidgets.QPushButton(self.groupBox_3)
        self.but_delete.setObjectName("but_delete")
        self.gridLayout_3.addWidget(self.but_delete, 0, 3, 1, 1)
        self.but_color = QtWidgets.QPushButton(self.groupBox_3)
        self.but_color.setMinimumSize(QtCore.QSize(23, 23))
        self.but_color.setMaximumSize(QtCore.QSize(23, 23))
        self.but_color.setText("")
        self.but_color.setObjectName("but_color")
        self.gridLayout_3.addWidget(self.but_color, 0, 1, 1, 1)
        self.verticalLayout.addWidget(self.groupBox_3)
        self.groupBox_5 = QtWidgets.QGroupBox(Roi)
        self.groupBox_5.setCheckable(False)
        self.groupBox_5.setObjectName("groupBox_5")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBox_5)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.le_min_y = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_min_y.sizePolicy().hasHeightForWidth())
        self.le_min_y.setSizePolicy(sizePolicy)
        self.le_min_y.setMinimumSize(QtCore.QSize(0, 0))
        self.le_min_y.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_min_y.setAcceptDrops(False)
        self.le_min_y.setAlignment(QtCore.Qt.AlignCenter)
        self.le_min_y.setObjectName("le_min_y")
        self.gridLayout_4.addWidget(self.le_min_y, 2, 2, 1, 1)
        self.chk_show_max = QtWidgets.QCheckBox(self.groupBox_5)
        self.chk_show_max.setText("")
        self.chk_show_max.setObjectName("chk_show_max")
        self.gridLayout_4.addWidget(self.chk_show_max, 1, 4, 1, 1)
        self.le_min_v = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_min_v.sizePolicy().hasHeightForWidth())
        self.le_min_v.setSizePolicy(sizePolicy)
        self.le_min_v.setMinimumSize(QtCore.QSize(0, 0))
        self.le_min_v.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_min_v.setAcceptDrops(False)
        self.le_min_v.setAlignment(QtCore.Qt.AlignCenter)
        self.le_min_v.setObjectName("le_min_v")
        self.gridLayout_4.addWidget(self.le_min_v, 2, 3, 1, 1)
        self.le_max_v = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_max_v.sizePolicy().hasHeightForWidth())
        self.le_max_v.setSizePolicy(sizePolicy)
        self.le_max_v.setMinimumSize(QtCore.QSize(0, 0))
        self.le_max_v.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_max_v.setAcceptDrops(False)
        self.le_max_v.setAlignment(QtCore.Qt.AlignCenter)
        self.le_max_v.setObjectName("le_max_v")
        self.gridLayout_4.addWidget(self.le_max_v, 1, 3, 1, 1)
        self.le_min_x = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_min_x.sizePolicy().hasHeightForWidth())
        self.le_min_x.setSizePolicy(sizePolicy)
        self.le_min_x.setMinimumSize(QtCore.QSize(0, 0))
        self.le_min_x.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_min_x.setAcceptDrops(False)
        self.le_min_x.setAlignment(QtCore.Qt.AlignCenter)
        self.le_min_x.setObjectName("le_min_x")
        self.gridLayout_4.addWidget(self.le_min_x, 2, 1, 1, 1)
        self.chk_show_min = QtWidgets.QCheckBox(self.groupBox_5)
        self.chk_show_min.setText("")
        self.chk_show_min.setObjectName("chk_show_min")
        self.gridLayout_4.addWidget(self.chk_show_min, 2, 4, 1, 1)
        self.le_com_x = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_com_x.sizePolicy().hasHeightForWidth())
        self.le_com_x.setSizePolicy(sizePolicy)
        self.le_com_x.setMinimumSize(QtCore.QSize(0, 0))
        self.le_com_x.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_com_x.setAcceptDrops(False)
        self.le_com_x.setAlignment(QtCore.Qt.AlignCenter)
        self.le_com_x.setObjectName("le_com_x")
        self.gridLayout_4.addWidget(self.le_com_x, 3, 1, 1, 1)
        self.label_15 = QtWidgets.QLabel(self.groupBox_5)
        self.label_15.setObjectName("label_15")
        self.gridLayout_4.addWidget(self.label_15, 3, 0, 1, 1)
        self.le_com_y = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_com_y.sizePolicy().hasHeightForWidth())
        self.le_com_y.setSizePolicy(sizePolicy)
        self.le_com_y.setMinimumSize(QtCore.QSize(0, 0))
        self.le_com_y.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_com_y.setAcceptDrops(False)
        self.le_com_y.setAlignment(QtCore.Qt.AlignCenter)
        self.le_com_y.setObjectName("le_com_y")
        self.gridLayout_4.addWidget(self.le_com_y, 3, 2, 1, 1)
        self.le_com_v = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_com_v.sizePolicy().hasHeightForWidth())
        self.le_com_v.setSizePolicy(sizePolicy)
        self.le_com_v.setMinimumSize(QtCore.QSize(0, 0))
        self.le_com_v.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_com_v.setAcceptDrops(False)
        self.le_com_v.setAlignment(QtCore.Qt.AlignCenter)
        self.le_com_v.setObjectName("le_com_v")
        self.gridLayout_4.addWidget(self.le_com_v, 3, 3, 1, 1)
        self.chk_show_com = QtWidgets.QCheckBox(self.groupBox_5)
        self.chk_show_com.setText("")
        self.chk_show_com.setObjectName("chk_show_com")
        self.gridLayout_4.addWidget(self.chk_show_com, 3, 4, 1, 1)
        self.le_fwhm_x = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_fwhm_x.sizePolicy().hasHeightForWidth())
        self.le_fwhm_x.setSizePolicy(sizePolicy)
        self.le_fwhm_x.setMinimumSize(QtCore.QSize(0, 0))
        self.le_fwhm_x.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_fwhm_x.setAcceptDrops(False)
        self.le_fwhm_x.setAlignment(QtCore.Qt.AlignCenter)
        self.le_fwhm_x.setObjectName("le_fwhm_x")
        self.gridLayout_4.addWidget(self.le_fwhm_x, 4, 1, 1, 1)
        self.le_sum = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_sum.sizePolicy().hasHeightForWidth())
        self.le_sum.setSizePolicy(sizePolicy)
        self.le_sum.setMinimumSize(QtCore.QSize(0, 0))
        self.le_sum.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_sum.setAcceptDrops(False)
        self.le_sum.setAlignment(QtCore.Qt.AlignCenter)
        self.le_sum.setObjectName("le_sum")
        self.gridLayout_4.addWidget(self.le_sum, 6, 1, 1, 1)
        self.sb_roi_bg = QtWidgets.QDoubleSpinBox(self.groupBox_5)
        self.sb_roi_bg.setMaximumSize(QtCore.QSize(110, 16777215))
        self.sb_roi_bg.setMaximum(99999999.0)
        self.sb_roi_bg.setObjectName("sb_roi_bg")
        self.gridLayout_4.addWidget(self.sb_roi_bg, 8, 1, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.groupBox_5)
        self.label_16.setObjectName("label_16")
        self.gridLayout_4.addWidget(self.label_16, 4, 0, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.groupBox_5)
        self.label_17.setObjectName("label_17")
        self.gridLayout_4.addWidget(self.label_17, 6, 0, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.groupBox_5)
        self.label_18.setObjectName("label_18")
        self.gridLayout_4.addWidget(self.label_18, 8, 0, 1, 1)
        self.label_14 = QtWidgets.QLabel(self.groupBox_5)
        self.label_14.setObjectName("label_14")
        self.gridLayout_4.addWidget(self.label_14, 2, 0, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.groupBox_5)
        self.label_13.setObjectName("label_13")
        self.gridLayout_4.addWidget(self.label_13, 1, 0, 1, 1)
        self.le_max_x = QtWidgets.QLineEdit(self.groupBox_5)
        self.le_max_x.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_max_x.sizePolicy().hasHeightForWidth())
        self.le_max_x.setSizePolicy(sizePolicy)
        self.le_max_x.setMinimumSize(QtCore.QSize(0, 0))
        self.le_max_x.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_max_x.setAcceptDrops(False)
        self.le_max_x.setAlignment(QtCore.Qt.AlignCenter)
        self.le_max_x.setObjectName("le_max_x")
        self.gridLayout_4.addWidget(self.le_max_x, 1, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.groupBox_5)
        self.label_10.setAlignment(QtCore.Qt.AlignCenter)
        self.label_10.setObjectName("label_10")
        self.gridLayout_4.addWidget(self.label_10, 0, 1, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.groupBox_5)
        self.label_11.setAlignment(QtCore.Qt.AlignCenter)
        self.label_11.setObjectName("label_11")
        self.gridLayout_4.addWidget(self.label_11, 0, 2, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.groupBox_5)
        self.label_12.setAlignment(QtCore.Qt.AlignCenter)
        self.label_12.setObjectName("label_12")
        self.gridLayout_4.addWidget(self.label_12, 0, 3, 1, 1)
        self.le_max_y = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_max_y.sizePolicy().hasHeightForWidth())
        self.le_max_y.setSizePolicy(sizePolicy)
        self.le_max_y.setMinimumSize(QtCore.QSize(0, 0))
        self.le_max_y.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_max_y.setAcceptDrops(False)
        self.le_max_y.setAlignment(QtCore.Qt.AlignCenter)
        self.le_max_y.setObjectName("le_max_y")
        self.gridLayout_4.addWidget(self.le_max_y, 1, 2, 1, 1)
        self.le_fwhm_y = QtWidgets.QLineEdit(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.le_fwhm_y.sizePolicy().hasHeightForWidth())
        self.le_fwhm_y.setSizePolicy(sizePolicy)
        self.le_fwhm_y.setMinimumSize(QtCore.QSize(0, 0))
        self.le_fwhm_y.setMaximumSize(QtCore.QSize(100, 16777215))
        self.le_fwhm_y.setAcceptDrops(False)
        self.le_fwhm_y.setAlignment(QtCore.Qt.AlignCenter)
        self.le_fwhm_y.setObjectName("le_fwhm_y")
        self.gridLayout_4.addWidget(self.le_fwhm_y, 4, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem, 4, 3, 1, 1)
        self.label_21 = QtWidgets.QLabel(self.groupBox_5)
        self.label_21.setObjectName("label_21")
        self.gridLayout_4.addWidget(self.label_21, 0, 4, 1, 1)
        self.verticalLayout.addWidget(self.groupBox_5)

        self.retranslateUi(Roi)
        QtCore.QMetaObject.connectSlotsByName(Roi)

    def retranslateUi(self, Roi):
        _translate = QtCore.QCoreApplication.translate
        Roi.setWindowTitle(_translate("Roi", "Form"))
        self.groupBox_3.setTitle(_translate("Roi", "ROI"))
        self.label_6.setText(_translate("Roi", "X:"))
        self.chb_roi_enable.setText(_translate("Roi", "Enable"))
        self.label_8.setText(_translate("Roi", "H:"))
        self.label_9.setText(_translate("Roi", "W:"))
        self.label_7.setText(_translate("Roi", "Y:"))
        self.but_delete.setText(_translate("Roi", "Delete ROI"))
        self.but_color.setToolTip(_translate("Roi", "color"))
        self.groupBox_5.setTitle(_translate("Roi", "Statistics"))
        self.label_15.setText(_translate("Roi", "CoM"))
        self.label_16.setText(_translate("Roi", "FWHM"))
        self.label_17.setText(_translate("Roi", "Sum"))
        self.label_18.setText(_translate("Roi", "BG"))
        self.label_14.setText(_translate("Roi", "Min"))
        self.label_13.setText(_translate("Roi", "Max"))
        self.label_10.setText(_translate("Roi", "X"))
        self.label_11.setText(_translate("Roi", "Y"))
        self.label_12.setText(_translate("Roi", "Value"))
        self.label_21.setText(_translate("Roi", "Mark"))

